@@ -36,6 +36,21 @@ def commit_push_changes(message):
             filepath = __main__.os.path.join(path,'pubspec.yaml')
             version = change_version.get_version(filepath, 'standard')
             
+        if __main__.os.path.exists(__main__.os.path.join(path, 'setup.py')):
+            __main__.arch_type = 'other'
+            filepath = __main__.os.path.join(path, 'setup.py')
+            version = change_version.get_version(filepath, 'custom')
+            
+        if __main__.os.path.exists(__main__.os.path.join(path, 'config/app.php')):
+            __main__.arch_type = 'other'
+            filepath = __main__.os.path.join(path, 'config/app.php')
+            version = change_version.get_version(filepath, 'custom')
+            
+        if __main__.os.path.exists(__main__.os.path.join(path, 'config/app_config.php')):
+            __main__.arch_type = 'other'
+            filepath = __main__.os.path.join(path, 'config/app.php_config')
+            version = change_version.get_version(filepath, 'custom')
+            
         if __main__.debug == 1:
             print("DEBUG: Project type found: ", __main__.arch_type)
 
